clear all

%Outputs of function CP_DLD_gamma are [yk,gk,Dck],
%where yk is matrix with length values for each section (columns) and each
%gamma value (rows), gk is matrix with gap values for each section (columns) and each
%gamma value (rows), and Dck an array of particle size being filter by each
%section

% CIRCLE PILLARS
%% Select the desire DR(Dp_min), NoS, and gamma_min 
%(can modify other values as desired except for gamma_max)
%Variables related to particule sizes
Dp_min = 1;
Dp_max = 10;
%Number of sections (each section will be k)
NoS_k = 5;
%Parameters to evaluate pillar diameter to gap ratio
gamma_min = 0.3;
gamma_step_less1 = 0.3;
gamma_step_high1 = 0.3;
gamma_max = 3;
%Fabrication limits
gk_fablim = 2;
D0k_fablim = 6;

%Calling function "CP_DLD_gamma"
[yk,yk_normalized,gk,Dck,gamma] = ...
    CP_DLD_gamma(Dp_min,Dp_max,gamma_min,gamma_step_less1,...
    gk_fablim,D0k_fablim,NoS_k,gamma_max,gamma_step_high1);

%*****Plots*****
figure;bar3(yk_normalized)
xlabel('k, section number')
ylabel('Gamma')
set(gca,'YTick',1:length(gamma))
set(gca,'YTickLabel',gamma)
%yticklabels(num2str(gamma))
zlabel('Length, L (normalized)')

figure;bar3(yk./1000)
xlabel('k, section number')
ylabel('Gamma')
set(gca,'YTick',1:length(gamma))
set(gca,'YTickLabel',gamma)
%yticklabels(num2str(gamma))
zlabel('Section length (mm)')

%% Fig. 7 of the paper 
Dp_array = [0.01 1];
NoS = [5 10];
for i=1:length(Dp_array)
    for NoS_k=1:length(NoS)   %Number of sections (each section will be k)
        %Variables related to particule sizes
        Dp_min = Dp_array(i);
        Dp_max = 10;
        %Parameters to evaluate pillar diameter to gap ratio
        gamma_min = 0.3;
        gamma_step_less1 = 0.3;
        gamma_step_high1 = 0.3;
        gamma_max = 3;
        %Fabrication limits
        gk_fablim = 2; 
        D0k_fablim = 6; 

        %Calling function "CP_DLD_gamma"
        [yk,yk_normalized,gk,Dck,gamma] = ...
            CP_DLD_gamma(Dp_min,Dp_max,gamma_min,gamma_step_less1,...
            gk_fablim,D0k_fablim,NoS(NoS_k),gamma_max,gamma_step_high1);

        %*****Plots*****
        figure;bar3(yk_normalized)
        xlabel('k, section number')
        ylabel('Gamma')
        set(gca,'YTick',1:length(gamma))
        set(gca,'YTickLabel',gamma)
        zlabel('Length, L (normalized)')
        title(strcat('Dp_min =',num2str(Dp_min),' and NoS = ',num2str(NoS(NoS_k))))

        figure;bar3(yk./1000)
        xlabel('k, section number')
        ylabel('Gamma')
        set(gca,'YTick',1:length(gamma))
        set(gca,'YTickLabel',gamma)
        zlabel('Section length (mm)')
        title(strcat('Dp_min =',num2str(Dp_min),' and NoS = ',num2str(NoS(NoS_k))))
        
    end
end

%% Fig.8 and Fig. 9: Total length of a device vs NoS for different Dp values
col_array = ['b','g','m'];
Dp_array = [0.01 0.1 1];
figure;
for i=1:length(Dp_array)
    for NoS_k=2:10
       %Variables related to particule sizes
        Dp_min = Dp_array(i);
        Dp_max = 10;
        %Parameters to evaluate pillar diameter to gap ratio
        gamma_min = 0.3;
        gamma_step_less1 = 0.3;
        gamma_step_high1 = 0.3;
        gamma_max = 3;
        %Fabrication limits
        gk_fablim = 2; 
        D0k_fablim = 6; 

        %Calling function "CP_DLD_gamma"
        [yk,yk_normalized,gk,Dck,gamma] = ...
            CP_DLD_gamma(Dp_min,Dp_max,gamma_min,gamma_step_less1,...
            gk_fablim,D0k_fablim,NoS_k,gamma_max,gamma_step_high1);
        
        for j=1:NoS_k
            Min_length(j)=min(yk(:,j));
            s(i).gamma(NoS_k,j)=gamma(find(yk(:,j)==min(yk(:,j))));
        end
        if NoS_k==2
            TotalMinL_samegamma(i,NoS_k)=min(yk);
            TotalMinL_samegamma_value(i,NoS_k)=gamma(find(yk==min(yk)));
        else
            TotalMinL_samegamma(i,NoS_k)=min(sum(yk'));
            TotalMinL_samegamma_value(i,NoS_k)=gamma(find(sum(yk')==min(sum(yk'))));
        end
        
        LvsNoS(i,NoS_k)=sum(Min_length);
        clear Min_length
    end

    plot(2:NoS_k,LvsNoS(i,2:end)./1000,'-o','Color',col_array(i),'LineWidth', 2,'MarkerSize',5)
    ylim([0 1000]) %[0 6]
    hold on
    plot(find(LvsNoS(i,2:end)==min(LvsNoS(i,2:end))),min(LvsNoS(i,2:end))/1000,'*','Color','k','LineWidth', 2,'MarkerSize',9)
end
xlabel('NoS')
ylabel('Overall shortest length when using different gammas per section')
hold off

figure
for i=1:length(Dp_array)
   plot(2:NoS_k,LvsNoS(i,2:end)./TotalMinL_samegamma(i,:),'-o','Color',col_array(i),'LineWidth', 2,'MarkerSize',5)
   hold on 
end
xlabel('NoS')
ylabel('Ratio of overall shortest length using different gammas per section and shortest length using the same gamma for all')
hold off

