%Declaration of variables
%Section (Critical Dimension) Scale Factor, SSF [alpha], Dc(k)=SSF*Dc(k+1)
%Number of Section, NoS [k], i form 1 to NoS
%Separation Device Length, L
%Dc, DLD critical dimension
%Separation Device Resolution, DR (Dcmin) = f(SN,SSF)
%**************************Theory**********************************
clear all

%% Plot 1 of ISCAS paper; L vs K (1:30) for different alphas(1.5 - 3.4, 0.2 step) without Dcmin
clear all

SSF_array = 1.5:0.1:3.4; %alpha
NoS_array = 1:15; %k
DR_array = [0.01, 0.1, 1];

[L,Dcmin,pos_001, pA_001, pos_01, pA_01, pos_1, pA_1] = DLD_theory(SSF_array,NoS_array,DR_array);
L = L./1000; %to convert units from micrometers to milimeters

%Individual plot for L vs K for different alphas
figure;
CO(:,:,1) = ones(length(SSF_array)).*linspace(0,0.8,length(SSF_array)); % red
CO(:,:,2) = ones(length(SSF_array)).*linspace(0.5,1,length(SSF_array)); % green
CO(:,:,3) = ones(length(SSF_array)).*linspace(0,0.1,length(SSF_array)); % blue
plot(NoS_array,L(1,:),'LineWidth',3,'color',[CO(1,1,1) CO(1,1,2) CO(1,1,3)]);
%legend(strcat('alpha = ',num2str(alfa(1))))
for n=2:length(SSF_array)
    hold on;
    plot(NoS_array,L(n,:),'LineWidth',3,'color',[CO(1,n,1) CO(1,n,2) CO(1,n,3)]);
    %plot(NoS_array,L(n,:))%,'DisplayName',strcat('alpha = ',num2str(alfa(n))));
end
title('L vs NoS: Theoretical Analysis')
xlabel('Number of Sections, NoS')
ylabel('Separation Device Length, L (mm)') %\mum
grid on
ylim([0.2 2.2]);
figure;imagesc(SSF_array,SSF_array,CO)

%% Plot 2 of ISCAS paper; L vs alpha (1.1 - 3.4) for different NoS (1 - 10)
clear all

SSF_array = 1.1:0.1:3.4; %alpha
NoS_array = 1:15; %k
DR_array = [0.01, 0.1, 1];

[L,Dcmin,pos_001, pA_001, pos_01, pA_01, pos_1, pA_1] = DLD_theory(SSF_array,NoS_array,DR_array);
L = L./1000; %to convert units from micrometers to milimeters
Lt = L';
%Individual plot for L vs K for different alphas
figure;
CO(:,:,1) = ones(length(NoS_array)).*linspace(0,0,length(NoS_array)); % red
CO(:,:,2) = ones(length(NoS_array)).*linspace(0,0.3,length(NoS_array)); % green
CO(:,:,3) = ones(length(NoS_array)).*linspace(0,1,length(NoS_array)); % blue
plot(SSF_array,Lt(1,:),'LineWidth',3,'color',[CO(1,1,1) CO(1,1,2) CO(1,1,3)]);
%legend(strcat('alpha = ',num2str(alfa(1))))
for n=2:length(NoS_array)
    hold on;
    plot(SSF_array,Lt(n,:),'LineWidth',3,'color',[CO(1,n,1) CO(1,n,2) CO(1,n,3)]);
    %plot(NoS_array,L(n,:))%,'DisplayName',strcat('alpha = ',num2str(alfa(n))));
end
title('L vs SSF: Theoretical Analysis')
xlabel('Section Scale Factor, SSF')
ylabel('Separation Device Length, L (mm)') %\mum
grid on
ylim([0 2.2]);
figure;imagesc(NoS_array,NoS_array,CO)

%% Plot 3 of ISCAS paper; 3D plot - L vs NoS vs SSF (1.1 - 3.4) for different NoS (1 - 10)
clear all

SSF_array = 1.1:0.1:3.4; %alpha
NoS_array = 1:15; %k
DR_array = [0.01, 0.1, 1];

[L,Dcmin,pos_001, pA_001, pos_01, pA_01, pos_1, pA_1] = DLD_theory(SSF_array,NoS_array,DR_array);
L = L./1000; %to convert units from micrometers to milimeters
%pos_X is the position on k
%pA_X is the position of the alpha value
figure
surf(NoS_array,SSF_array,L)
xlabel('Number of Sections, NoS')
ylabel('Section Scale Factor, SSF')
zlabel('Separation Device Length, L (mm)') %\mum
hold on
for i=1:length(pos_001)
    hold on; plot3(pos_001(i),SSF_array(pA_001(i)),L(pA_001(i),pos_001(i)),'mo','LineWidth',2,'MarkerSize',5);
end
for i=1:length(pos_01)
    hold on; plot3(pos_01(i),SSF_array(pA_01(i)),L(pA_01(i),pos_01(i)),'ko','LineWidth',2,'MarkerSize',5);
end
for i=1:length(pos_1)
    hold on; plot3(pos_1(i),SSF_array(pA_1(i)),L(pA_1(i),pos_1(i)),'co','LineWidth',2,'MarkerSize',5);
end
hold off

%% Plot 4
clear all

SSF_array = 1.1:0.1:3.4; %alpha
NoS_array = 1:15; %k
DR_array = [0.01, 0.1, 1];

[L,Dcmin,pos_001, pA_001, pos_01, pA_01, pos_1, pA_1] = DLD_theory(SSF_array,NoS_array,DR_array);

% %***********No log scale
% figure;
% CO(:,:,1) = ones(length(SSF_array)).*linspace(0,0.8,length(SSF_array)); % red linspace(0.5,1,length(SSF_array))
% CO(:,:,2) = ones(length(SSF_array)).*linspace(0.5,1,length(SSF_array)); % green linspace(0,0.8,length(SSF_array))
% CO(:,:,3) = ones(length(SSF_array)).*linspace(0,0.1,length(SSF_array)); % blue linspace(0,0.1,length(SSF_array))
% plot(NoS_array,Dcmin(1,:),'LineWidth',2,'color',[CO(1,1,1) CO(1,1,2) CO(1,1,3)]);
% for n=2:length(SSF_array)
%     hold on;
%     plot(NoS_array,Dcmin(n,:),'LineWidth',2,'color',[CO(1,n,1) CO(1,n,2) CO(1,n,3)]);
% end
% title('DR vs NoS: Theoretical Analysis')
% xlabel('Number of Sections, NoS')
% ylabel('Separation Device Resolution, DR (in \mum)')
% grid on
% figure;imagesc(SSF_array,SSF_array,CO)

%************Log scale
figure;
CO(:,:,1) = ones(length(SSF_array)).*linspace(0,0.8,length(SSF_array)); % red
CO(:,:,2) = ones(length(SSF_array)).*linspace(0.5,1,length(SSF_array)); % green
CO(:,:,3) = ones(length(SSF_array)).*linspace(0,0.1,length(SSF_array)); % blue
semilogy(NoS_array,Dcmin(1,:),'LineWidth',2,'color',[CO(1,1,1) CO(1,1,2) CO(1,1,3)]);
for n=2:length(SSF_array)
    hold on;
    semilogy(NoS_array,Dcmin(n,:),'LineWidth',2,'color',[CO(1,n,1) CO(1,n,2) CO(1,n,3)]);
end
title('DR vs NoS: Theoretical Analysis')
xlabel('Number of Sections, NoS')
ylabel('Separation Device Resolution, DR (in \mum)')
grid on
figure;imagesc(SSF_array,SSF_array,CO)

% %% Individual plot for L vs K for different alphas with Dcmin
% figure;
% plot(k,L(1,:),'k');
% for n=2:length(alfa)
%     hold on; plot(k,L(n,:),'k');
%     for i=1:length(pos_001)
%         hold on; plot(pos_001(i),L(pA_001(i),pos_001(i)),'bo','LineWidth',2,'MarkerSize',5);
%     end
%     for i=1:length(pos_01)
%         hold on; plot(pos_01(i),L(pA_01(i),pos_01(i)),'go','LineWidth',2,'MarkerSize',5);
%     end
%     for i=1:length(pos_1)
%         hold on; plot(pos_1(i),L(pA_1(i),pos_1(i)),'ro','LineWidth',2,'MarkerSize',5);
%     end
% end
% grid on;
% title('L vs K')
% xlabel('Number of sections, K')
% ylabel('Length of the device')
